@@ -83,7 +83,7 @@ def sync_detailed(
         job_id (Union[Unset, None, str]):
         include_header (Union[Unset, None, str]):
         queue_limit (Union[Unset, None, str]):
-        json_body (OpenaiSyncScriptByPathJsonBody):
+        json_body (OpenaiSyncScriptByPathJsonBody): The arguments to pass to the script or flow
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -130,7 +130,7 @@ async def asyncio_detailed(
         job_id (Union[Unset, None, str]):
         include_header (Union[Unset, None, str]):
         queue_limit (Union[Unset, None, str]):
-        json_body (OpenaiSyncScriptByPathJsonBody):
+        json_body (OpenaiSyncScriptByPathJsonBody): The arguments to pass to the script or flow
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
