@@ -106,7 +106,7 @@ def sync_detailed(
         job_id (Union[Unset, None, str]):
         include_header (Union[Unset, None, str]):
         invisible_to_owner (Union[Unset, None, bool]):
-        json_body (RunFlowByPathJsonBody):
+        json_body (RunFlowByPathJsonBody): The arguments to pass to the script or flow
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -165,7 +165,7 @@ async def asyncio_detailed(
         job_id (Union[Unset, None, str]):
         include_header (Union[Unset, None, str]):
         invisible_to_owner (Union[Unset, None, bool]):
-        json_body (RunFlowByPathJsonBody):
+        json_body (RunFlowByPathJsonBody): The arguments to pass to the script or flow
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
