@@ -6,19 +6,33 @@ import httpx
 from ... import errors
 from ...client import AuthenticatedClient, Client
 from ...models.list_variable_response_200_item import ListVariableResponse200Item
-from ...types import Response
+from ...types import UNSET, Response, Unset
 
 
 def _get_kwargs(
     workspace: str,
+    *,
+    path_start: Union[Unset, None, str] = UNSET,
+    page: Union[Unset, None, int] = UNSET,
+    per_page: Union[Unset, None, int] = UNSET,
 ) -> Dict[str, Any]:
     pass
 
+    params: Dict[str, Any] = {}
+    params["path_start"] = path_start
+
+    params["page"] = page
+
+    params["per_page"] = per_page
+
+    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
+
     return {
         "method": "get",
         "url": "/w/{workspace}/variables/list".format(
             workspace=workspace,
         ),
+        "params": params,
     }
 
 
@@ -55,11 +69,17 @@ def sync_detailed(
     workspace: str,
     *,
     client: Union[AuthenticatedClient, Client],
+    path_start: Union[Unset, None, str] = UNSET,
+    page: Union[Unset, None, int] = UNSET,
+    per_page: Union[Unset, None, int] = UNSET,
 ) -> Response[List["ListVariableResponse200Item"]]:
     """list variables
 
     Args:
         workspace (str):
+        path_start (Union[Unset, None, str]):
+        page (Union[Unset, None, int]):
+        per_page (Union[Unset, None, int]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -71,6 +91,9 @@ def sync_detailed(
 
     kwargs = _get_kwargs(
         workspace=workspace,
+        path_start=path_start,
+        page=page,
+        per_page=per_page,
     )
 
     response = client.get_httpx_client().request(
@@ -84,11 +107,17 @@ def sync(
     workspace: str,
     *,
     client: Union[AuthenticatedClient, Client],
+    path_start: Union[Unset, None, str] = UNSET,
+    page: Union[Unset, None, int] = UNSET,
+    per_page: Union[Unset, None, int] = UNSET,
 ) -> Optional[List["ListVariableResponse200Item"]]:
     """list variables
 
     Args:
         workspace (str):
+        path_start (Union[Unset, None, str]):
+        page (Union[Unset, None, int]):
+        per_page (Union[Unset, None, int]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -101,6 +130,9 @@ def sync(
     return sync_detailed(
         workspace=workspace,
         client=client,
+        path_start=path_start,
+        page=page,
+        per_page=per_page,
     ).parsed
 
 
@@ -108,11 +140,17 @@ async def asyncio_detailed(
     workspace: str,
     *,
     client: Union[AuthenticatedClient, Client],
+    path_start: Union[Unset, None, str] = UNSET,
+    page: Union[Unset, None, int] = UNSET,
+    per_page: Union[Unset, None, int] = UNSET,
 ) -> Response[List["ListVariableResponse200Item"]]:
     """list variables
 
     Args:
         workspace (str):
+        path_start (Union[Unset, None, str]):
+        page (Union[Unset, None, int]):
+        per_page (Union[Unset, None, int]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -124,6 +162,9 @@ async def asyncio_detailed(
 
     kwargs = _get_kwargs(
         workspace=workspace,
+        path_start=path_start,
+        page=page,
+        per_page=per_page,
     )
 
     response = await client.get_async_httpx_client().request(**kwargs)
@@ -135,11 +176,17 @@ async def asyncio(
     workspace: str,
     *,
     client: Union[AuthenticatedClient, Client],
+    path_start: Union[Unset, None, str] = UNSET,
+    page: Union[Unset, None, int] = UNSET,
+    per_page: Union[Unset, None, int] = UNSET,
 ) -> Optional[List["ListVariableResponse200Item"]]:
     """list variables
 
     Args:
         workspace (str):
+        path_start (Union[Unset, None, str]):
+        page (Union[Unset, None, int]):
+        per_page (Union[Unset, None, int]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -153,5 +200,8 @@ async def asyncio(
         await asyncio_detailed(
             workspace=workspace,
             client=client,
+            path_start=path_start,
+            page=page,
+            per_page=per_page,
         )
     ).parsed
