@@ -1,8 +1,10 @@
-from typing import Any, Dict, Union
+from http import HTTPStatus
+from typing import Any, Dict, Optional, Union
 
 import httpx
 
-from ...client import Client
+from ... import errors
+from ...client import AuthenticatedClient, Client
 from ...models.update_variable_json_body import UpdateVariableJsonBody
 from ...types import UNSET, Response, Unset
 
@@ -11,14 +13,10 @@ def _get_kwargs(
     workspace: str,
     path: str,
     *,
-    client: Client,
     json_body: UpdateVariableJsonBody,
     already_encrypted: Union[Unset, None, bool] = UNSET,
 ) -> Dict[str, Any]:
-    url = "{}/w/{workspace}/variables/update/{path}".format(client.base_url, workspace=workspace, path=path)
-
-    headers: Dict[str, str] = client.get_headers()
-    cookies: Dict[str, Any] = client.get_cookies()
+    pass
 
     params: Dict[str, Any] = {}
     params["already_encrypted"] = already_encrypted
@@ -29,21 +27,28 @@ def _get_kwargs(
 
     return {
         "method": "post",
-        "url": url,
-        "headers": headers,
-        "cookies": cookies,
-        "timeout": client.get_timeout(),
+        "url": "/w/{workspace}/variables/update/{path}".format(
+            workspace=workspace,
+            path=path,
+        ),
         "json": json_json_body,
         "params": params,
     }
 
 
-def _build_response(*, response: httpx.Response) -> Response[Any]:
+def _parse_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Optional[Any]:
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(response.status_code, response.content)
+    else:
+        return None
+
+
+def _build_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Response[Any]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=None,
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -51,7 +56,7 @@ def sync_detailed(
     workspace: str,
     path: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     json_body: UpdateVariableJsonBody,
     already_encrypted: Union[Unset, None, bool] = UNSET,
 ) -> Response[Any]:
@@ -63,6 +68,10 @@ def sync_detailed(
         already_encrypted (Union[Unset, None, bool]):
         json_body (UpdateVariableJsonBody):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[Any]
     """
@@ -70,24 +79,22 @@ def sync_detailed(
     kwargs = _get_kwargs(
         workspace=workspace,
         path=path,
-        client=client,
         json_body=json_body,
         already_encrypted=already_encrypted,
     )
 
-    response = httpx.request(
-        verify=client.verify_ssl,
+    response = client.get_httpx_client().request(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio_detailed(
     workspace: str,
     path: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     json_body: UpdateVariableJsonBody,
     already_encrypted: Union[Unset, None, bool] = UNSET,
 ) -> Response[Any]:
@@ -99,6 +106,10 @@ async def asyncio_detailed(
         already_encrypted (Union[Unset, None, bool]):
         json_body (UpdateVariableJsonBody):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[Any]
     """
@@ -106,12 +117,10 @@ async def asyncio_detailed(
     kwargs = _get_kwargs(
         workspace=workspace,
         path=path,
-        client=client,
         json_body=json_body,
         already_encrypted=already_encrypted,
     )
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
+    response = await client.get_async_httpx_client().request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
