@@ -7,6 +7,12 @@ from ..models.completed_job_flow_status_failure_module_type import CompletedJobF
 from ..types import UNSET, Unset
 
 if TYPE_CHECKING:
+    from ..models.completed_job_flow_status_failure_module_agent_actions_item_type_0 import (
+        CompletedJobFlowStatusFailureModuleAgentActionsItemType0,
+    )
+    from ..models.completed_job_flow_status_failure_module_agent_actions_item_type_1 import (
+        CompletedJobFlowStatusFailureModuleAgentActionsItemType1,
+    )
     from ..models.completed_job_flow_status_failure_module_approvers_item import (
         CompletedJobFlowStatusFailureModuleApproversItem,
     )
@@ -37,6 +43,9 @@ class CompletedJobFlowStatusFailureModule:
         approvers (Union[Unset, List['CompletedJobFlowStatusFailureModuleApproversItem']]):
         failed_retries (Union[Unset, List[str]]):
         skipped (Union[Unset, bool]):
+        agent_actions (Union[Unset, List[Union['CompletedJobFlowStatusFailureModuleAgentActionsItemType0',
+            'CompletedJobFlowStatusFailureModuleAgentActionsItemType1']]]):
+        agent_actions_success (Union[Unset, List[bool]]):
         parent_module (Union[Unset, str]):
     """
 
@@ -53,10 +62,24 @@ class CompletedJobFlowStatusFailureModule:
     approvers: Union[Unset, List["CompletedJobFlowStatusFailureModuleApproversItem"]] = UNSET
     failed_retries: Union[Unset, List[str]] = UNSET
     skipped: Union[Unset, bool] = UNSET
+    agent_actions: Union[
+        Unset,
+        List[
+            Union[
+                "CompletedJobFlowStatusFailureModuleAgentActionsItemType0",
+                "CompletedJobFlowStatusFailureModuleAgentActionsItemType1",
+            ]
+        ],
+    ] = UNSET
+    agent_actions_success: Union[Unset, List[bool]] = UNSET
     parent_module: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
+        from ..models.completed_job_flow_status_failure_module_agent_actions_item_type_0 import (
+            CompletedJobFlowStatusFailureModuleAgentActionsItemType0,
+        )
+
         type = self.type.value
 
         id = self.id
@@ -96,6 +119,24 @@ class CompletedJobFlowStatusFailureModule:
             failed_retries = self.failed_retries
 
         skipped = self.skipped
+        agent_actions: Union[Unset, List[Dict[str, Any]]] = UNSET
+        if not isinstance(self.agent_actions, Unset):
+            agent_actions = []
+            for agent_actions_item_data in self.agent_actions:
+                agent_actions_item: Dict[str, Any]
+
+                if isinstance(agent_actions_item_data, CompletedJobFlowStatusFailureModuleAgentActionsItemType0):
+                    agent_actions_item = agent_actions_item_data.to_dict()
+
+                else:
+                    agent_actions_item = agent_actions_item_data.to_dict()
+
+                agent_actions.append(agent_actions_item)
+
+        agent_actions_success: Union[Unset, List[bool]] = UNSET
+        if not isinstance(self.agent_actions_success, Unset):
+            agent_actions_success = self.agent_actions_success
+
         parent_module = self.parent_module
 
         field_dict: Dict[str, Any] = {}
@@ -129,6 +170,10 @@ class CompletedJobFlowStatusFailureModule:
             field_dict["failed_retries"] = failed_retries
         if skipped is not UNSET:
             field_dict["skipped"] = skipped
+        if agent_actions is not UNSET:
+            field_dict["agent_actions"] = agent_actions
+        if agent_actions_success is not UNSET:
+            field_dict["agent_actions_success"] = agent_actions_success
         if parent_module is not UNSET:
             field_dict["parent_module"] = parent_module
 
@@ -136,6 +181,12 @@ class CompletedJobFlowStatusFailureModule:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.completed_job_flow_status_failure_module_agent_actions_item_type_0 import (
+            CompletedJobFlowStatusFailureModuleAgentActionsItemType0,
+        )
+        from ..models.completed_job_flow_status_failure_module_agent_actions_item_type_1 import (
+            CompletedJobFlowStatusFailureModuleAgentActionsItemType1,
+        )
         from ..models.completed_job_flow_status_failure_module_approvers_item import (
             CompletedJobFlowStatusFailureModuleApproversItem,
         )
@@ -196,6 +247,36 @@ class CompletedJobFlowStatusFailureModule:
 
         skipped = d.pop("skipped", UNSET)
 
+        agent_actions = []
+        _agent_actions = d.pop("agent_actions", UNSET)
+        for agent_actions_item_data in _agent_actions or []:
+
+            def _parse_agent_actions_item(
+                data: object,
+            ) -> Union[
+                "CompletedJobFlowStatusFailureModuleAgentActionsItemType0",
+                "CompletedJobFlowStatusFailureModuleAgentActionsItemType1",
+            ]:
+                try:
+                    if not isinstance(data, dict):
+                        raise TypeError()
+                    agent_actions_item_type_0 = CompletedJobFlowStatusFailureModuleAgentActionsItemType0.from_dict(data)
+
+                    return agent_actions_item_type_0
+                except:  # noqa: E722
+                    pass
+                if not isinstance(data, dict):
+                    raise TypeError()
+                agent_actions_item_type_1 = CompletedJobFlowStatusFailureModuleAgentActionsItemType1.from_dict(data)
+
+                return agent_actions_item_type_1
+
+            agent_actions_item = _parse_agent_actions_item(agent_actions_item_data)
+
+            agent_actions.append(agent_actions_item)
+
+        agent_actions_success = cast(List[bool], d.pop("agent_actions_success", UNSET))
+
         parent_module = d.pop("parent_module", UNSET)
 
         completed_job_flow_status_failure_module = cls(
@@ -212,6 +293,8 @@ class CompletedJobFlowStatusFailureModule:
             approvers=approvers,
             failed_retries=failed_retries,
             skipped=skipped,
+            agent_actions=agent_actions,
+            agent_actions_success=agent_actions_success,
             parent_module=parent_module,
         )
 
