@@ -10,6 +10,7 @@ if TYPE_CHECKING:
     from ..models.flow_preview_value_failure_module_retry_exponential import (
         FlowPreviewValueFailureModuleRetryExponential,
     )
+    from ..models.flow_preview_value_failure_module_retry_retry_if import FlowPreviewValueFailureModuleRetryRetryIf
 
 
 T = TypeVar("T", bound="FlowPreviewValueFailureModuleRetry")
@@ -21,10 +22,12 @@ class FlowPreviewValueFailureModuleRetry:
     Attributes:
         constant (Union[Unset, FlowPreviewValueFailureModuleRetryConstant]):
         exponential (Union[Unset, FlowPreviewValueFailureModuleRetryExponential]):
+        retry_if (Union[Unset, FlowPreviewValueFailureModuleRetryRetryIf]):
     """
 
     constant: Union[Unset, "FlowPreviewValueFailureModuleRetryConstant"] = UNSET
     exponential: Union[Unset, "FlowPreviewValueFailureModuleRetryExponential"] = UNSET
+    retry_if: Union[Unset, "FlowPreviewValueFailureModuleRetryRetryIf"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -36,6 +39,10 @@ class FlowPreviewValueFailureModuleRetry:
         if not isinstance(self.exponential, Unset):
             exponential = self.exponential.to_dict()
 
+        retry_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.retry_if, Unset):
+            retry_if = self.retry_if.to_dict()
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update({})
@@ -43,6 +50,8 @@ class FlowPreviewValueFailureModuleRetry:
             field_dict["constant"] = constant
         if exponential is not UNSET:
             field_dict["exponential"] = exponential
+        if retry_if is not UNSET:
+            field_dict["retry_if"] = retry_if
 
         return field_dict
 
@@ -52,6 +61,7 @@ class FlowPreviewValueFailureModuleRetry:
         from ..models.flow_preview_value_failure_module_retry_exponential import (
             FlowPreviewValueFailureModuleRetryExponential,
         )
+        from ..models.flow_preview_value_failure_module_retry_retry_if import FlowPreviewValueFailureModuleRetryRetryIf
 
         d = src_dict.copy()
         _constant = d.pop("constant", UNSET)
@@ -68,9 +78,17 @@ class FlowPreviewValueFailureModuleRetry:
         else:
             exponential = FlowPreviewValueFailureModuleRetryExponential.from_dict(_exponential)
 
+        _retry_if = d.pop("retry_if", UNSET)
+        retry_if: Union[Unset, FlowPreviewValueFailureModuleRetryRetryIf]
+        if isinstance(_retry_if, Unset):
+            retry_if = UNSET
+        else:
+            retry_if = FlowPreviewValueFailureModuleRetryRetryIf.from_dict(_retry_if)
+
         flow_preview_value_failure_module_retry = cls(
             constant=constant,
             exponential=exponential,
+            retry_if=retry_if,
         )
 
         flow_preview_value_failure_module_retry.additional_properties = d
