@@ -8,6 +8,7 @@ from ..types import UNSET, Unset
 if TYPE_CHECKING:
     from ..models.flow_preview_value_modules_item_retry_constant import FlowPreviewValueModulesItemRetryConstant
     from ..models.flow_preview_value_modules_item_retry_exponential import FlowPreviewValueModulesItemRetryExponential
+    from ..models.flow_preview_value_modules_item_retry_retry_if import FlowPreviewValueModulesItemRetryRetryIf
 
 
 T = TypeVar("T", bound="FlowPreviewValueModulesItemRetry")
@@ -19,10 +20,12 @@ class FlowPreviewValueModulesItemRetry:
     Attributes:
         constant (Union[Unset, FlowPreviewValueModulesItemRetryConstant]):
         exponential (Union[Unset, FlowPreviewValueModulesItemRetryExponential]):
+        retry_if (Union[Unset, FlowPreviewValueModulesItemRetryRetryIf]):
     """
 
     constant: Union[Unset, "FlowPreviewValueModulesItemRetryConstant"] = UNSET
     exponential: Union[Unset, "FlowPreviewValueModulesItemRetryExponential"] = UNSET
+    retry_if: Union[Unset, "FlowPreviewValueModulesItemRetryRetryIf"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -34,6 +37,10 @@ class FlowPreviewValueModulesItemRetry:
         if not isinstance(self.exponential, Unset):
             exponential = self.exponential.to_dict()
 
+        retry_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.retry_if, Unset):
+            retry_if = self.retry_if.to_dict()
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update({})
@@ -41,6 +48,8 @@ class FlowPreviewValueModulesItemRetry:
             field_dict["constant"] = constant
         if exponential is not UNSET:
             field_dict["exponential"] = exponential
+        if retry_if is not UNSET:
+            field_dict["retry_if"] = retry_if
 
         return field_dict
 
@@ -50,6 +59,7 @@ class FlowPreviewValueModulesItemRetry:
         from ..models.flow_preview_value_modules_item_retry_exponential import (
             FlowPreviewValueModulesItemRetryExponential,
         )
+        from ..models.flow_preview_value_modules_item_retry_retry_if import FlowPreviewValueModulesItemRetryRetryIf
 
         d = src_dict.copy()
         _constant = d.pop("constant", UNSET)
@@ -66,9 +76,17 @@ class FlowPreviewValueModulesItemRetry:
         else:
             exponential = FlowPreviewValueModulesItemRetryExponential.from_dict(_exponential)
 
+        _retry_if = d.pop("retry_if", UNSET)
+        retry_if: Union[Unset, FlowPreviewValueModulesItemRetryRetryIf]
+        if isinstance(_retry_if, Unset):
+            retry_if = UNSET
+        else:
+            retry_if = FlowPreviewValueModulesItemRetryRetryIf.from_dict(_retry_if)
+
         flow_preview_value_modules_item_retry = cls(
             constant=constant,
             exponential=exponential,
+            retry_if=retry_if,
         )
 
         flow_preview_value_modules_item_retry.additional_properties = d
