@@ -7,6 +7,12 @@ from ..models.flow_status_failure_module_type import FlowStatusFailureModuleType
 from ..types import UNSET, Unset
 
 if TYPE_CHECKING:
+    from ..models.flow_status_failure_module_agent_actions_item_type_0 import (
+        FlowStatusFailureModuleAgentActionsItemType0,
+    )
+    from ..models.flow_status_failure_module_agent_actions_item_type_1 import (
+        FlowStatusFailureModuleAgentActionsItemType1,
+    )
     from ..models.flow_status_failure_module_approvers_item import FlowStatusFailureModuleApproversItem
     from ..models.flow_status_failure_module_branch_chosen import FlowStatusFailureModuleBranchChosen
     from ..models.flow_status_failure_module_branchall import FlowStatusFailureModuleBranchall
@@ -33,6 +39,9 @@ class FlowStatusFailureModule:
         approvers (Union[Unset, List['FlowStatusFailureModuleApproversItem']]):
         failed_retries (Union[Unset, List[str]]):
         skipped (Union[Unset, bool]):
+        agent_actions (Union[Unset, List[Union['FlowStatusFailureModuleAgentActionsItemType0',
+            'FlowStatusFailureModuleAgentActionsItemType1']]]):
+        agent_actions_success (Union[Unset, List[bool]]):
         parent_module (Union[Unset, str]):
     """
 
@@ -49,10 +58,19 @@ class FlowStatusFailureModule:
     approvers: Union[Unset, List["FlowStatusFailureModuleApproversItem"]] = UNSET
     failed_retries: Union[Unset, List[str]] = UNSET
     skipped: Union[Unset, bool] = UNSET
+    agent_actions: Union[
+        Unset,
+        List[Union["FlowStatusFailureModuleAgentActionsItemType0", "FlowStatusFailureModuleAgentActionsItemType1"]],
+    ] = UNSET
+    agent_actions_success: Union[Unset, List[bool]] = UNSET
     parent_module: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
+        from ..models.flow_status_failure_module_agent_actions_item_type_0 import (
+            FlowStatusFailureModuleAgentActionsItemType0,
+        )
+
         type = self.type.value
 
         id = self.id
@@ -92,6 +110,24 @@ class FlowStatusFailureModule:
             failed_retries = self.failed_retries
 
         skipped = self.skipped
+        agent_actions: Union[Unset, List[Dict[str, Any]]] = UNSET
+        if not isinstance(self.agent_actions, Unset):
+            agent_actions = []
+            for agent_actions_item_data in self.agent_actions:
+                agent_actions_item: Dict[str, Any]
+
+                if isinstance(agent_actions_item_data, FlowStatusFailureModuleAgentActionsItemType0):
+                    agent_actions_item = agent_actions_item_data.to_dict()
+
+                else:
+                    agent_actions_item = agent_actions_item_data.to_dict()
+
+                agent_actions.append(agent_actions_item)
+
+        agent_actions_success: Union[Unset, List[bool]] = UNSET
+        if not isinstance(self.agent_actions_success, Unset):
+            agent_actions_success = self.agent_actions_success
+
         parent_module = self.parent_module
 
         field_dict: Dict[str, Any] = {}
@@ -125,6 +161,10 @@ class FlowStatusFailureModule:
             field_dict["failed_retries"] = failed_retries
         if skipped is not UNSET:
             field_dict["skipped"] = skipped
+        if agent_actions is not UNSET:
+            field_dict["agent_actions"] = agent_actions
+        if agent_actions_success is not UNSET:
+            field_dict["agent_actions_success"] = agent_actions_success
         if parent_module is not UNSET:
             field_dict["parent_module"] = parent_module
 
@@ -132,6 +172,12 @@ class FlowStatusFailureModule:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.flow_status_failure_module_agent_actions_item_type_0 import (
+            FlowStatusFailureModuleAgentActionsItemType0,
+        )
+        from ..models.flow_status_failure_module_agent_actions_item_type_1 import (
+            FlowStatusFailureModuleAgentActionsItemType1,
+        )
         from ..models.flow_status_failure_module_approvers_item import FlowStatusFailureModuleApproversItem
         from ..models.flow_status_failure_module_branch_chosen import FlowStatusFailureModuleBranchChosen
         from ..models.flow_status_failure_module_branchall import FlowStatusFailureModuleBranchall
@@ -184,6 +230,33 @@ class FlowStatusFailureModule:
 
         skipped = d.pop("skipped", UNSET)
 
+        agent_actions = []
+        _agent_actions = d.pop("agent_actions", UNSET)
+        for agent_actions_item_data in _agent_actions or []:
+
+            def _parse_agent_actions_item(
+                data: object,
+            ) -> Union["FlowStatusFailureModuleAgentActionsItemType0", "FlowStatusFailureModuleAgentActionsItemType1"]:
+                try:
+                    if not isinstance(data, dict):
+                        raise TypeError()
+                    agent_actions_item_type_0 = FlowStatusFailureModuleAgentActionsItemType0.from_dict(data)
+
+                    return agent_actions_item_type_0
+                except:  # noqa: E722
+                    pass
+                if not isinstance(data, dict):
+                    raise TypeError()
+                agent_actions_item_type_1 = FlowStatusFailureModuleAgentActionsItemType1.from_dict(data)
+
+                return agent_actions_item_type_1
+
+            agent_actions_item = _parse_agent_actions_item(agent_actions_item_data)
+
+            agent_actions.append(agent_actions_item)
+
+        agent_actions_success = cast(List[bool], d.pop("agent_actions_success", UNSET))
+
         parent_module = d.pop("parent_module", UNSET)
 
         flow_status_failure_module = cls(
@@ -200,6 +273,8 @@ class FlowStatusFailureModule:
             approvers=approvers,
             failed_retries=failed_retries,
             skipped=skipped,
+            agent_actions=agent_actions,
+            agent_actions_success=agent_actions_success,
             parent_module=parent_module,
         )
 
