@@ -12,6 +12,9 @@ if TYPE_CHECKING:
     from ..models.get_completed_job_response_200_raw_flow_failure_module_retry_exponential import (
         GetCompletedJobResponse200RawFlowFailureModuleRetryExponential,
     )
+    from ..models.get_completed_job_response_200_raw_flow_failure_module_retry_retry_if import (
+        GetCompletedJobResponse200RawFlowFailureModuleRetryRetryIf,
+    )
 
 
 T = TypeVar("T", bound="GetCompletedJobResponse200RawFlowFailureModuleRetry")
@@ -23,10 +26,12 @@ class GetCompletedJobResponse200RawFlowFailureModuleRetry:
     Attributes:
         constant (Union[Unset, GetCompletedJobResponse200RawFlowFailureModuleRetryConstant]):
         exponential (Union[Unset, GetCompletedJobResponse200RawFlowFailureModuleRetryExponential]):
+        retry_if (Union[Unset, GetCompletedJobResponse200RawFlowFailureModuleRetryRetryIf]):
     """
 
     constant: Union[Unset, "GetCompletedJobResponse200RawFlowFailureModuleRetryConstant"] = UNSET
     exponential: Union[Unset, "GetCompletedJobResponse200RawFlowFailureModuleRetryExponential"] = UNSET
+    retry_if: Union[Unset, "GetCompletedJobResponse200RawFlowFailureModuleRetryRetryIf"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -38,6 +43,10 @@ class GetCompletedJobResponse200RawFlowFailureModuleRetry:
         if not isinstance(self.exponential, Unset):
             exponential = self.exponential.to_dict()
 
+        retry_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.retry_if, Unset):
+            retry_if = self.retry_if.to_dict()
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update({})
@@ -45,6 +54,8 @@ class GetCompletedJobResponse200RawFlowFailureModuleRetry:
             field_dict["constant"] = constant
         if exponential is not UNSET:
             field_dict["exponential"] = exponential
+        if retry_if is not UNSET:
+            field_dict["retry_if"] = retry_if
 
         return field_dict
 
@@ -56,6 +67,9 @@ class GetCompletedJobResponse200RawFlowFailureModuleRetry:
         from ..models.get_completed_job_response_200_raw_flow_failure_module_retry_exponential import (
             GetCompletedJobResponse200RawFlowFailureModuleRetryExponential,
         )
+        from ..models.get_completed_job_response_200_raw_flow_failure_module_retry_retry_if import (
+            GetCompletedJobResponse200RawFlowFailureModuleRetryRetryIf,
+        )
 
         d = src_dict.copy()
         _constant = d.pop("constant", UNSET)
@@ -72,9 +86,17 @@ class GetCompletedJobResponse200RawFlowFailureModuleRetry:
         else:
             exponential = GetCompletedJobResponse200RawFlowFailureModuleRetryExponential.from_dict(_exponential)
 
+        _retry_if = d.pop("retry_if", UNSET)
+        retry_if: Union[Unset, GetCompletedJobResponse200RawFlowFailureModuleRetryRetryIf]
+        if isinstance(_retry_if, Unset):
+            retry_if = UNSET
+        else:
+            retry_if = GetCompletedJobResponse200RawFlowFailureModuleRetryRetryIf.from_dict(_retry_if)
+
         get_completed_job_response_200_raw_flow_failure_module_retry = cls(
             constant=constant,
             exponential=exponential,
+            retry_if=retry_if,
         )
 
         get_completed_job_response_200_raw_flow_failure_module_retry.additional_properties = d
