@@ -2,7 +2,7 @@ from enum import Enum
 
 
 class GetFlowByPathResponse200ValueModulesItemSuspendUserGroupsRequiredType0Type(str, Enum):
-    JAVASCRIPT = "javascript"
+    STATIC = "static"
 
     def __str__(self) -> str:
         return str(self.value)
