@@ -12,6 +12,9 @@ if TYPE_CHECKING:
     from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_retry_exponential import (
         GetHubFlowByIdResponse200FlowValueModulesItemRetryExponential,
     )
+    from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_retry_retry_if import (
+        GetHubFlowByIdResponse200FlowValueModulesItemRetryRetryIf,
+    )
 
 
 T = TypeVar("T", bound="GetHubFlowByIdResponse200FlowValueModulesItemRetry")
@@ -23,10 +26,12 @@ class GetHubFlowByIdResponse200FlowValueModulesItemRetry:
     Attributes:
         constant (Union[Unset, GetHubFlowByIdResponse200FlowValueModulesItemRetryConstant]):
         exponential (Union[Unset, GetHubFlowByIdResponse200FlowValueModulesItemRetryExponential]):
+        retry_if (Union[Unset, GetHubFlowByIdResponse200FlowValueModulesItemRetryRetryIf]):
     """
 
     constant: Union[Unset, "GetHubFlowByIdResponse200FlowValueModulesItemRetryConstant"] = UNSET
     exponential: Union[Unset, "GetHubFlowByIdResponse200FlowValueModulesItemRetryExponential"] = UNSET
+    retry_if: Union[Unset, "GetHubFlowByIdResponse200FlowValueModulesItemRetryRetryIf"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -38,6 +43,10 @@ class GetHubFlowByIdResponse200FlowValueModulesItemRetry:
         if not isinstance(self.exponential, Unset):
             exponential = self.exponential.to_dict()
 
+        retry_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.retry_if, Unset):
+            retry_if = self.retry_if.to_dict()
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update({})
@@ -45,6 +54,8 @@ class GetHubFlowByIdResponse200FlowValueModulesItemRetry:
             field_dict["constant"] = constant
         if exponential is not UNSET:
             field_dict["exponential"] = exponential
+        if retry_if is not UNSET:
+            field_dict["retry_if"] = retry_if
 
         return field_dict
 
@@ -56,6 +67,9 @@ class GetHubFlowByIdResponse200FlowValueModulesItemRetry:
         from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_retry_exponential import (
             GetHubFlowByIdResponse200FlowValueModulesItemRetryExponential,
         )
+        from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_retry_retry_if import (
+            GetHubFlowByIdResponse200FlowValueModulesItemRetryRetryIf,
+        )
 
         d = src_dict.copy()
         _constant = d.pop("constant", UNSET)
@@ -72,9 +86,17 @@ class GetHubFlowByIdResponse200FlowValueModulesItemRetry:
         else:
             exponential = GetHubFlowByIdResponse200FlowValueModulesItemRetryExponential.from_dict(_exponential)
 
+        _retry_if = d.pop("retry_if", UNSET)
+        retry_if: Union[Unset, GetHubFlowByIdResponse200FlowValueModulesItemRetryRetryIf]
+        if isinstance(_retry_if, Unset):
+            retry_if = UNSET
+        else:
+            retry_if = GetHubFlowByIdResponse200FlowValueModulesItemRetryRetryIf.from_dict(_retry_if)
+
         get_hub_flow_by_id_response_200_flow_value_modules_item_retry = cls(
             constant=constant,
             exponential=exponential,
+            retry_if=retry_if,
         )
 
         get_hub_flow_by_id_response_200_flow_value_modules_item_retry.additional_properties = d
