@@ -1,4 +1,4 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
@@ -6,6 +6,12 @@ from attrs import field as _attrs_field
 from ..models.get_large_file_storage_config_response_200_type import GetLargeFileStorageConfigResponse200Type
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.get_large_file_storage_config_response_200_secondary_storage import (
+        GetLargeFileStorageConfigResponse200SecondaryStorage,
+    )
+
+
 T = TypeVar("T", bound="GetLargeFileStorageConfigResponse200")
 
 
@@ -16,13 +22,17 @@ class GetLargeFileStorageConfigResponse200:
         type (Union[Unset, GetLargeFileStorageConfigResponse200Type]):
         s3_resource_path (Union[Unset, str]):
         azure_blob_resource_path (Union[Unset, str]):
+        gcs_resource_path (Union[Unset, str]):
         public_resource (Union[Unset, bool]):
+        secondary_storage (Union[Unset, GetLargeFileStorageConfigResponse200SecondaryStorage]):
     """
 
     type: Union[Unset, GetLargeFileStorageConfigResponse200Type] = UNSET
     s3_resource_path: Union[Unset, str] = UNSET
     azure_blob_resource_path: Union[Unset, str] = UNSET
+    gcs_resource_path: Union[Unset, str] = UNSET
     public_resource: Union[Unset, bool] = UNSET
+    secondary_storage: Union[Unset, "GetLargeFileStorageConfigResponse200SecondaryStorage"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -32,7 +42,11 @@ class GetLargeFileStorageConfigResponse200:
 
         s3_resource_path = self.s3_resource_path
         azure_blob_resource_path = self.azure_blob_resource_path
+        gcs_resource_path = self.gcs_resource_path
         public_resource = self.public_resource
+        secondary_storage: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.secondary_storage, Unset):
+            secondary_storage = self.secondary_storage.to_dict()
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -43,13 +57,21 @@ class GetLargeFileStorageConfigResponse200:
             field_dict["s3_resource_path"] = s3_resource_path
         if azure_blob_resource_path is not UNSET:
             field_dict["azure_blob_resource_path"] = azure_blob_resource_path
+        if gcs_resource_path is not UNSET:
+            field_dict["gcs_resource_path"] = gcs_resource_path
         if public_resource is not UNSET:
             field_dict["public_resource"] = public_resource
+        if secondary_storage is not UNSET:
+            field_dict["secondary_storage"] = secondary_storage
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.get_large_file_storage_config_response_200_secondary_storage import (
+            GetLargeFileStorageConfigResponse200SecondaryStorage,
+        )
+
         d = src_dict.copy()
         _type = d.pop("type", UNSET)
         type: Union[Unset, GetLargeFileStorageConfigResponse200Type]
@@ -62,13 +84,24 @@ class GetLargeFileStorageConfigResponse200:
 
         azure_blob_resource_path = d.pop("azure_blob_resource_path", UNSET)
 
+        gcs_resource_path = d.pop("gcs_resource_path", UNSET)
+
         public_resource = d.pop("public_resource", UNSET)
 
+        _secondary_storage = d.pop("secondary_storage", UNSET)
+        secondary_storage: Union[Unset, GetLargeFileStorageConfigResponse200SecondaryStorage]
+        if isinstance(_secondary_storage, Unset):
+            secondary_storage = UNSET
+        else:
+            secondary_storage = GetLargeFileStorageConfigResponse200SecondaryStorage.from_dict(_secondary_storage)
+
         get_large_file_storage_config_response_200 = cls(
             type=type,
             s3_resource_path=s3_resource_path,
             azure_blob_resource_path=azure_blob_resource_path,
+            gcs_resource_path=gcs_resource_path,
             public_resource=public_resource,
+            secondary_storage=secondary_storage,
         )
 
         get_large_file_storage_config_response_200.additional_properties = d
