@@ -1,7 +1,9 @@
+import datetime
 from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
+from dateutil.parser import isoparse
 
 from ..types import UNSET, Unset
 
@@ -23,6 +25,8 @@ class GetResourceResponse200:
         description (Union[Unset, str]):
         value (Union[Unset, Any]):
         extra_perms (Union[Unset, GetResourceResponse200ExtraPerms]):
+        created_by (Union[Unset, str]):
+        edited_at (Union[Unset, datetime.datetime]):
     """
 
     path: str
@@ -32,6 +36,8 @@ class GetResourceResponse200:
     description: Union[Unset, str] = UNSET
     value: Union[Unset, Any] = UNSET
     extra_perms: Union[Unset, "GetResourceResponse200ExtraPerms"] = UNSET
+    created_by: Union[Unset, str] = UNSET
+    edited_at: Union[Unset, datetime.datetime] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -45,6 +51,11 @@ class GetResourceResponse200:
         if not isinstance(self.extra_perms, Unset):
             extra_perms = self.extra_perms.to_dict()
 
+        created_by = self.created_by
+        edited_at: Union[Unset, str] = UNSET
+        if not isinstance(self.edited_at, Unset):
+            edited_at = self.edited_at.isoformat()
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -62,6 +73,10 @@ class GetResourceResponse200:
             field_dict["value"] = value
         if extra_perms is not UNSET:
             field_dict["extra_perms"] = extra_perms
+        if created_by is not UNSET:
+            field_dict["created_by"] = created_by
+        if edited_at is not UNSET:
+            field_dict["edited_at"] = edited_at
 
         return field_dict
 
@@ -89,6 +104,15 @@ class GetResourceResponse200:
         else:
             extra_perms = GetResourceResponse200ExtraPerms.from_dict(_extra_perms)
 
+        created_by = d.pop("created_by", UNSET)
+
+        _edited_at = d.pop("edited_at", UNSET)
+        edited_at: Union[Unset, datetime.datetime]
+        if isinstance(_edited_at, Unset):
+            edited_at = UNSET
+        else:
+            edited_at = isoparse(_edited_at)
+
         get_resource_response_200 = cls(
             path=path,
             resource_type=resource_type,
@@ -97,6 +121,8 @@ class GetResourceResponse200:
             description=description,
             value=value,
             extra_perms=extra_perms,
+            created_by=created_by,
+            edited_at=edited_at,
         )
 
         get_resource_response_200.additional_properties = d
