@@ -52,7 +52,7 @@ class GetSuspendedJobFlowResponse200JobType1:
         scheduled_for (Union[Unset, datetime.datetime]):
         script_path (Union[Unset, str]):
         script_hash (Union[Unset, str]):
-        args (Union[Unset, GetSuspendedJobFlowResponse200JobType1Args]):
+        args (Union[Unset, GetSuspendedJobFlowResponse200JobType1Args]): The arguments to pass to the script or flow
         logs (Union[Unset, str]):
         raw_code (Union[Unset, str]):
         canceled_by (Union[Unset, str]):
