@@ -1,4 +1,4 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
@@ -6,6 +6,10 @@ from attrs import field as _attrs_field
 from ..models.git_repository_settings_exclude_types_override_item import GitRepositorySettingsExcludeTypesOverrideItem
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.git_repository_settings_settings import GitRepositorySettingsSettings
+
+
 T = TypeVar("T", bound="GitRepositorySettings")
 
 
@@ -17,6 +21,8 @@ class GitRepositorySettings:
         git_repo_resource_path (str):
         use_individual_branch (Union[Unset, bool]):
         group_by_folder (Union[Unset, bool]):
+        collapsed (Union[Unset, bool]):
+        settings (Union[Unset, GitRepositorySettingsSettings]):
         exclude_types_override (Union[Unset, List[GitRepositorySettingsExcludeTypesOverrideItem]]):
     """
 
@@ -24,6 +30,8 @@ class GitRepositorySettings:
     git_repo_resource_path: str
     use_individual_branch: Union[Unset, bool] = UNSET
     group_by_folder: Union[Unset, bool] = UNSET
+    collapsed: Union[Unset, bool] = UNSET
+    settings: Union[Unset, "GitRepositorySettingsSettings"] = UNSET
     exclude_types_override: Union[Unset, List[GitRepositorySettingsExcludeTypesOverrideItem]] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
@@ -32,6 +40,11 @@ class GitRepositorySettings:
         git_repo_resource_path = self.git_repo_resource_path
         use_individual_branch = self.use_individual_branch
         group_by_folder = self.group_by_folder
+        collapsed = self.collapsed
+        settings: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.settings, Unset):
+            settings = self.settings.to_dict()
+
         exclude_types_override: Union[Unset, List[str]] = UNSET
         if not isinstance(self.exclude_types_override, Unset):
             exclude_types_override = []
@@ -52,6 +65,10 @@ class GitRepositorySettings:
             field_dict["use_individual_branch"] = use_individual_branch
         if group_by_folder is not UNSET:
             field_dict["group_by_folder"] = group_by_folder
+        if collapsed is not UNSET:
+            field_dict["collapsed"] = collapsed
+        if settings is not UNSET:
+            field_dict["settings"] = settings
         if exclude_types_override is not UNSET:
             field_dict["exclude_types_override"] = exclude_types_override
 
@@ -59,6 +76,8 @@ class GitRepositorySettings:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.git_repository_settings_settings import GitRepositorySettingsSettings
+
         d = src_dict.copy()
         script_path = d.pop("script_path")
 
@@ -68,6 +87,15 @@ class GitRepositorySettings:
 
         group_by_folder = d.pop("group_by_folder", UNSET)
 
+        collapsed = d.pop("collapsed", UNSET)
+
+        _settings = d.pop("settings", UNSET)
+        settings: Union[Unset, GitRepositorySettingsSettings]
+        if isinstance(_settings, Unset):
+            settings = UNSET
+        else:
+            settings = GitRepositorySettingsSettings.from_dict(_settings)
+
         exclude_types_override = []
         _exclude_types_override = d.pop("exclude_types_override", UNSET)
         for exclude_types_override_item_data in _exclude_types_override or []:
@@ -82,6 +110,8 @@ class GitRepositorySettings:
             git_repo_resource_path=git_repo_resource_path,
             use_individual_branch=use_individual_branch,
             group_by_folder=group_by_folder,
+            collapsed=collapsed,
+            settings=settings,
             exclude_types_override=exclude_types_override,
         )
 
