@@ -16,12 +16,14 @@ class ListWorkspacesAsSuperAdminResponse200Item:
         name (str):
         owner (str):
         domain (Union[Unset, str]):
+        color (Union[Unset, str]):
     """
 
     id: str
     name: str
     owner: str
     domain: Union[Unset, str] = UNSET
+    color: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -29,6 +31,7 @@ class ListWorkspacesAsSuperAdminResponse200Item:
         name = self.name
         owner = self.owner
         domain = self.domain
+        color = self.color
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -41,6 +44,8 @@ class ListWorkspacesAsSuperAdminResponse200Item:
         )
         if domain is not UNSET:
             field_dict["domain"] = domain
+        if color is not UNSET:
+            field_dict["color"] = color
 
         return field_dict
 
@@ -55,11 +60,14 @@ class ListWorkspacesAsSuperAdminResponse200Item:
 
         domain = d.pop("domain", UNSET)
 
+        color = d.pop("color", UNSET)
+
         list_workspaces_as_super_admin_response_200_item = cls(
             id=id,
             name=name,
             owner=owner,
             domain=domain,
+            color=color,
         )
 
         list_workspaces_as_super_admin_response_200_item.additional_properties = d
