@@ -1,4 +1,4 @@
-from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Type, TypeVar, Union
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
@@ -22,12 +22,16 @@ class MainArgSignature:
         star_args (bool):
         args (List['MainArgSignatureArgsItem']):
         star_kwargs (Union[Unset, bool]):
+        no_main_func (Optional[bool]):
+        has_preprocessor (Optional[bool]):
     """
 
     type: MainArgSignatureType
     error: str
     star_args: bool
     args: List["MainArgSignatureArgsItem"]
+    no_main_func: Optional[bool]
+    has_preprocessor: Optional[bool]
     star_kwargs: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
@@ -43,6 +47,8 @@ class MainArgSignature:
             args.append(args_item)
 
         star_kwargs = self.star_kwargs
+        no_main_func = self.no_main_func
+        has_preprocessor = self.has_preprocessor
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -52,6 +58,8 @@ class MainArgSignature:
                 "error": error,
                 "star_args": star_args,
                 "args": args,
+                "no_main_func": no_main_func,
+                "has_preprocessor": has_preprocessor,
             }
         )
         if star_kwargs is not UNSET:
@@ -79,12 +87,18 @@ class MainArgSignature:
 
         star_kwargs = d.pop("star_kwargs", UNSET)
 
+        no_main_func = d.pop("no_main_func")
+
+        has_preprocessor = d.pop("has_preprocessor")
+
         main_arg_signature = cls(
             type=type,
             error=error,
             star_args=star_args,
             args=args,
             star_kwargs=star_kwargs,
+            no_main_func=no_main_func,
+            has_preprocessor=has_preprocessor,
         )
 
         main_arg_signature.additional_properties = d
