@@ -14,6 +14,8 @@ if TYPE_CHECKING:
     from ..models.whileloop_flow_modules_item_stop_after_all_iters_if import WhileloopFlowModulesItemStopAfterAllItersIf
     from ..models.whileloop_flow_modules_item_stop_after_if import WhileloopFlowModulesItemStopAfterIf
     from ..models.whileloop_flow_modules_item_suspend import WhileloopFlowModulesItemSuspend
+    from ..models.whileloop_flow_modules_item_timeout_type_0 import WhileloopFlowModulesItemTimeoutType0
+    from ..models.whileloop_flow_modules_item_timeout_type_1 import WhileloopFlowModulesItemTimeoutType1
 
 
 T = TypeVar("T", bound="WhileloopFlowModulesItem")
@@ -30,7 +32,7 @@ class WhileloopFlowModulesItem:
         skip_if (Union[Unset, WhileloopFlowModulesItemSkipIf]):
         sleep (Union['WhileloopFlowModulesItemSleepType0', 'WhileloopFlowModulesItemSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
-        timeout (Union[Unset, float]):
+        timeout (Union['WhileloopFlowModulesItemTimeoutType0', 'WhileloopFlowModulesItemTimeoutType1', Unset]):
         delete_after_use (Union[Unset, bool]):
         summary (Union[Unset, str]):
         mock (Union[Unset, WhileloopFlowModulesItemMock]):
@@ -47,7 +49,7 @@ class WhileloopFlowModulesItem:
     skip_if: Union[Unset, "WhileloopFlowModulesItemSkipIf"] = UNSET
     sleep: Union["WhileloopFlowModulesItemSleepType0", "WhileloopFlowModulesItemSleepType1", Unset] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
-    timeout: Union[Unset, float] = UNSET
+    timeout: Union["WhileloopFlowModulesItemTimeoutType0", "WhileloopFlowModulesItemTimeoutType1", Unset] = UNSET
     delete_after_use: Union[Unset, bool] = UNSET
     summary: Union[Unset, str] = UNSET
     mock: Union[Unset, "WhileloopFlowModulesItemMock"] = UNSET
@@ -59,6 +61,7 @@ class WhileloopFlowModulesItem:
 
     def to_dict(self) -> Dict[str, Any]:
         from ..models.whileloop_flow_modules_item_sleep_type_0 import WhileloopFlowModulesItemSleepType0
+        from ..models.whileloop_flow_modules_item_timeout_type_0 import WhileloopFlowModulesItemTimeoutType0
 
         id = self.id
         value = self.value
@@ -89,7 +92,20 @@ class WhileloopFlowModulesItem:
                 sleep = self.sleep.to_dict()
 
         cache_ttl = self.cache_ttl
-        timeout = self.timeout
+        timeout: Union[Dict[str, Any], Unset]
+        if isinstance(self.timeout, Unset):
+            timeout = UNSET
+
+        elif isinstance(self.timeout, WhileloopFlowModulesItemTimeoutType0):
+            timeout = UNSET
+            if not isinstance(self.timeout, Unset):
+                timeout = self.timeout.to_dict()
+
+        else:
+            timeout = UNSET
+            if not isinstance(self.timeout, Unset):
+                timeout = self.timeout.to_dict()
+
         delete_after_use = self.delete_after_use
         summary = self.summary
         mock: Union[Unset, Dict[str, Any]] = UNSET
@@ -155,6 +171,8 @@ class WhileloopFlowModulesItem:
         )
         from ..models.whileloop_flow_modules_item_stop_after_if import WhileloopFlowModulesItemStopAfterIf
         from ..models.whileloop_flow_modules_item_suspend import WhileloopFlowModulesItemSuspend
+        from ..models.whileloop_flow_modules_item_timeout_type_0 import WhileloopFlowModulesItemTimeoutType0
+        from ..models.whileloop_flow_modules_item_timeout_type_1 import WhileloopFlowModulesItemTimeoutType1
 
         d = src_dict.copy()
         id = d.pop("id")
@@ -215,7 +233,36 @@ class WhileloopFlowModulesItem:
 
         cache_ttl = d.pop("cache_ttl", UNSET)
 
-        timeout = d.pop("timeout", UNSET)
+        def _parse_timeout(
+            data: object,
+        ) -> Union["WhileloopFlowModulesItemTimeoutType0", "WhileloopFlowModulesItemTimeoutType1", Unset]:
+            if isinstance(data, Unset):
+                return data
+            try:
+                if not isinstance(data, dict):
+                    raise TypeError()
+                _timeout_type_0 = data
+                timeout_type_0: Union[Unset, WhileloopFlowModulesItemTimeoutType0]
+                if isinstance(_timeout_type_0, Unset):
+                    timeout_type_0 = UNSET
+                else:
+                    timeout_type_0 = WhileloopFlowModulesItemTimeoutType0.from_dict(_timeout_type_0)
+
+                return timeout_type_0
+            except:  # noqa: E722
+                pass
+            if not isinstance(data, dict):
+                raise TypeError()
+            _timeout_type_1 = data
+            timeout_type_1: Union[Unset, WhileloopFlowModulesItemTimeoutType1]
+            if isinstance(_timeout_type_1, Unset):
+                timeout_type_1 = UNSET
+            else:
+                timeout_type_1 = WhileloopFlowModulesItemTimeoutType1.from_dict(_timeout_type_1)
+
+            return timeout_type_1
+
+        timeout = _parse_timeout(d.pop("timeout", UNSET))
 
         delete_after_use = d.pop("delete_after_use", UNSET)
 
