@@ -2,7 +2,7 @@ from enum import Enum
 
 
 class WhileloopFlowType(str, Enum):
-    FORLOOPFLOW = "forloopflow"
+    WHILELOOPFLOW = "whileloopflow"
 
     def __str__(self) -> str:
         return str(self.value)
